﻿using System;
using System.Collections;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Presentation;
using Microsoft.SPOT.Presentation.Controls;
using Microsoft.SPOT.Presentation.Media;
using Microsoft.SPOT.Touch;

using Gadgeteer.Networking;
using GT = Gadgeteer;
using GTM = Gadgeteer.Modules;

namespace WifiRN171_Example
{
    public partial class Program
    {
        // This method is run when the mainboard is powered up or reset.  
        void ProgramStarted()
        {
            string methodName = "ProgramStarted";
            LogEnterMethod(methodName);

            wifi_RN171.Reboot();
            GT.Timer wifiInitializationTimer = new GT.Timer(1000);
            wifiInitializationTimer.Behavior = GT.Timer.BehaviorType.RunOnce;
            wifiInitializationTimer.Tick += initializeWifi;
            wifiInitializationTimer.Start();

            LogLeaveMethod(methodName);
        }

        void initializeWifi(GT.Timer timer)
        {
            string methodName = "initializeWifi";
            LogEnterMethod(methodName);

            wifi_RN171.SetDebugLevel(GTM.GHIElectronics.WiFi_RN171.DebugLevel.DebugAll);
            wifi_RN171.Initialize(GTM.GHIElectronics.WiFi_RN171.SocketProtocol.TCP_Server);
            wifi_RN171.EnableHttpServer(); //Enable HTTP Parsing
            wifi_RN171.HttpRequestReceived += new GTM.GHIElectronics.WiFi_RN171.HttpRequestReceivedHandler(wifi_RN171_HttpRequestReceived);
            
            LogLeaveMethod(methodName);
        }
        void wifi_RN171_HttpRequestReceived(GTM.GHIElectronics.HttpStream request)
        {
            string methodName = "wifi_RN171_HttpRequestReceived";
            LogEnterMethod(methodName);

            string requestedURL = request.Request.URL;
            // unfortunately /move.html?direction='north' is not working

            if (requestedURL.IndexOf("/_") == 0)
            {
                HandleAjaxHttpRequest(request, requestedURL);
            }
            else
            {
                HandleHttpRequest(request, requestedURL);
            }
            LogLeaveMethod(methodName);
        }

        private static void HandleHttpRequest(GTM.GHIElectronics.HttpStream request, string requestedURL)
        {
            string methodName = "HandleHttpRequest";
            LogEnterMethod(methodName);
            string action = "Unkown action";
            if (requestedURL == "/index.html")
            {
                action = "Welcome";
            }
            else
            {
                action = "Unknown action";

            }
            request.Response.HeaderData["Content-type"] = "text/html; charset=utf-8";
            request.Response.HeaderData["Connection"] = "close";
            request.Response.HeaderData["Cache-Control"] = "no-cache";
            request.Response.StatusCode = GTM.GHIElectronics.HttpResponse.ResponseStatus.OK;
            request.Response.Send("<!DOCTYPE html>\n<html lang=\"en\" xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n <meta charset=\"utf-8\" />\n <title></title>\n</head>\n \n<body>\n <style>\n td {\n width:160px;\n vertical-align:central\n }\n input[type=\"button\"] {\n font-size:144px;\n background-color:beige;\n text-align:center;\n color:black;\n font-weight:bold;\n width:150px;\n height:150px;\n vertical-align:central\n\n }\n\n input[type=\"button\"].x {\n font-size:12px;\n }\n\n #btnStop {\n background-color:red;\n font-size:32px;\n }\n\n #btnStart {\n background-color:green;\n font-size:32px;\n }\n #lbInfo {\n display: block;\n float: right;\n width:300px;\n background-color:white;\n font-size:24px;\n text-align:center\n }\n\n </style>\n <script type=\"text/javascript\">\n var xmlhttp;\n if (window.XMLHttpRequest) {\n xmlhttp = new XMLHttpRequest();\n }\n else {\n xmlhttp = new ActiveXObject(\"Microsoft.XMLHTTP\");\n }\n\n\n function move(direction) {\n \n xmlhttp.onreadystatechange = function () {\n if (xmlhttp.readyState == 4 && xmlhttp.status == 200) {\n  document.getElementById(\"lbInfo\").innerHTML = xmlhttp.responseText;\n }\n }\n xmlhttp.open(\"GET\", \"http://192.168.1.1/_\" + direction + \".html\", true);\n xmlhttp.send();\n };\n\n function northwest() { \n move('northwest');\n };\n function north() {\n \n move('north');\n };\n function northeast() {\n \n move('northeast');\n };\n function west() {\n move('west');\n };\n function doFire() {\n move('fire');\n };\n function east() {\n move('east');\n };\n function southwest() {\n move('southwest');\n };\n function south() {\n move('south');\n };\n function southeast() {\n move('southeast');\n };\n function doStart() {\n move('start');\n };\n function doStop() {\n move('stop');\n };\n\n </script>\n <table>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthWest\" onclick=\"northwest()\"/></td>\n <td><input type=\"button\" value=\"/\\\" id=\"btnUp\" onclick=\"north()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthEast\" onclick=\"northeast()\"/></td>\n <td></td>\n <td><input type=\"button\" value=\"STOP\" id=\"btnStop\" onclick=\"doStop()\"/></td>\n </tr>\n <tr>\n <td><input type=\"button\" value=\"<\" id=\"btnWest\" onclick=\"west()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnCenter\" onclick=\"doFire()\"/></td>\n <td><input type=\"button\" value=\">\" id=\"btnEast\" onclick=\"east()\"/></td>\n <td colspan=\"2\"><label id=\"lbInfo\">" + action + "</label></td>\n </tr>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthWest\" onclick=\"southwest()\"/></td>\n <td><input type=\"button\" value=\"\\/\" id=\"btnSouth\" onclick=\"south()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthEast\" onclick=\"southeast()\"/></td>\n <td></td>\n <td><input type=\"button\" value=\"START\" id=\"btnStart\" onclick=\"doStart()\"/></td>\n </tr>\n </table>\n</body>\n</html>");
            LogLeaveMethod(methodName);
        }

        private static void HandleAjaxHttpRequest(GTM.GHIElectronics.HttpStream request, string requestedURL)
        {
            string methodName = "HandleAjaxHttpRequest";
            LogEnterMethod(methodName);
            string action = "";
            switch (requestedURL)
            {
                case "/_index.html":
                    action = "Welcome";
                    break;
                case "/_northwest.html":
                    action += "north west";
                    break;
                case "/_north.html":
                    action += "north";
                    break;
                case "/_northeast.html":
                    action += "north east";
                    break;
                case "/_west.html":
                    action += "west";
                    break;
                case "/_center.html":
                    action += "home";
                    break;
                case "/_east.html":
                    action += "east";
                    break;
                case "/_southwest.html":
                    action += "south west";
                    break;
                case "/_south.html":
                    action = "We're going down south";
                    break;
                case "/_southeast.html":
                    action += "south east";
                    break;
                case "/_start.html":
                    action = "Let's go";
                    break;
                case "/_stop.html":
                    action = "Hold it, right there!";
                    break;
                case "/_fire.html":
                    action = "Cease fire!";
                    break;
                case "/_getposition.html":
                    action = "interval example position[x,y]";
                    break;
                default:
                    action = "Unknown action";
                    break;
            }
            //request.Response.StatusCode = GTM.GHIElectronics.HttpResponse.ResponseStatus.OK;
            request.Response.HeaderData["Content-type"] = "text/html; charset=utf-8";
            request.Response.HeaderData["Connection"] = "close";
            request.Response.HeaderData["Cache-Control"] = "no-cache";
            request.Response.StatusCode = GTM.GHIElectronics.HttpResponse.ResponseStatus.OK;
            request.Response.Send(action);
            LogLeaveMethod(methodName);
        }

        private static void LogEnterMethod(string methodName)
        {
            Debug.Print("---> " + methodName);
        }

        private static void LogLeaveMethod(string methodName)
        {
            Debug.Print("<--- " + methodName);
        }
    }
}
